==> open-xchange-documents-backend_7.6.3.orig.tar.bz2: open-xchange-documents-backend-7.6.3/com.openexchange.office.docx4j/src/main/java/org/docx4j/dml/chart/CTLineChart.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.

    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

 */


package org.docx4j.dml.chart;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;
import org.docx4j.dml.chart.layer.NoBarDirChart;
import org.docx4j.jaxb.Context;


/**
 * <p>Java class for CT_LineChart complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="CT_LineChart">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;group ref="{http://schemas.openxmlformats.org/drawingml/2006/chart}EG_LineChartShared"/>
 *         &lt;element name="hiLowLines" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_ChartLines" minOccurs="0"/>
 *         &lt;element name="upDownBars" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_UpDownBars" minOccurs="0"/>
 *         &lt;element name="marker" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_Boolean" minOccurs="0"/>
 *         &lt;element name="smooth" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_Boolean" minOccurs="0"/>
 *         &lt;element name="axId" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_UnsignedInt" maxOccurs="2" minOccurs="2"/>
 *         &lt;element name="extLst" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_ExtensionList" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_LineChart", propOrder = {
    "grouping",
    "varyColors",
    "ser",
    "dLbls",
    "dropLines",
    "hiLowLines",
    "upDownBars",
    "marker",
    "smooth",
    "axId",
    "extLst"
})
public class CTLineChart extends NoBarDirChart {

    @XmlElement(required = true)
    protected CTGrouping grouping;
    protected CTBoolean varyColors;
    @XmlElements({
        @XmlElement(name = "ser", type = CTLineSer.class)
    })
    protected List<ISerContent> ser;
    protected CTDLbls dLbls;
    protected CTChartLines dropLines;
    protected CTChartLines hiLowLines;
    protected CTUpDownBars upDownBars;
    protected CTBoolean marker;
    protected CTBoolean smooth;
    @XmlElement(required = true)
    protected List<CTUnsignedInt> axId;
    protected CTExtensionList extLst;

    /**
     * Gets the value of the grouping property.
     *
     * @return
     *     possible object is
     *     {@link CTGrouping }
     *
     */
    public CTGrouping getGrouping() {
        return grouping;
    }

    /**
     * Sets the value of the grouping property.
     *
     * @param value
     *     allowed object is
     *     {@link CTGrouping }
     *
     */
    public void setGrouping(CTGrouping value) {
        this.grouping = value;
    }

    /**
     * Gets the value of the varyColors property.
     *
     * @return
     *     possible object is
     *     {@link CTBoolean }
     *
     */
    @Override
    public CTBoolean getVaryColors() {
        return varyColors;
    }

    /**
     * Sets the value of the varyColors property.
     *
     * @param value
     *     allowed object is
     *     {@link CTBoolean }
     *
     */
    @Override
    public void setVaryColors(CTBoolean value) {
        this.varyColors = value;
    }

    /**
     * Gets the value of the ser property.
     *
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the ser property.
     *
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getSer().add(newItem);
     * </pre>
     *
     *
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTLineSer }
     *
     *
     */
    @Override
    public List<ISerContent> getSer() {
        if (ser == null) {
            ser = new ArrayList<ISerContent>();
        }
        return this.ser;
    }

    @Override
    public CTLineSer createSer() {
        return Context.getDmlChartObjectFactory().createCTLineSer();
    }

    /**
     * Gets the value of the dLbls property.
     *
     * @return
     *     possible object is
     *     {@link CTDLbls }
     *
     */
    public CTDLbls getDLbls() {
        return dLbls;
    }

    /**
     * Sets the value of the dLbls property.
     *
     * @param value
     *     allowed object is
     *     {@link CTDLbls }
     *
     */
    public void setDLbls(CTDLbls value) {
        this.dLbls = value;
    }

    /**
     * Gets the value of the dropLines property.
     *
     * @return
     *     possible object is
     *     {@link CTChartLines }
     *
     */
    public CTChartLines getDropLines() {
        return dropLines;
    }

    /**
     * Sets the value of the dropLines property.
     *
     * @param value
     *     allowed object is
     *     {@link CTChartLines }
     *
     */
    public void setDropLines(CTChartLines value) {
        this.dropLines = value;
    }

    /**
     * Gets the value of the hiLowLines property.
     *
     * @return
     *     possible object is
     *     {@link CTChartLines }
     *
     */
    public CTChartLines getHiLowLines() {
        return hiLowLines;
    }

    /**
     * Sets the value of the hiLowLines property.
     *
     * @param value
     *     allowed object is
     *     {@link CTChartLines }
     *
     */
    public void setHiLowLines(CTChartLines value) {
        this.hiLowLines = value;
    }

    /**
     * Gets the value of the upDownBars property.
     *
     * @return
     *     possible object is
     *     {@link CTUpDownBars }
     *
     */
    public CTUpDownBars getUpDownBars() {
        return upDownBars;
    }

    /**
     * Sets the value of the upDownBars property.
     *
     * @param value
     *     allowed object is
     *     {@link CTUpDownBars }
     *
     */
    public void setUpDownBars(CTUpDownBars value) {
        this.upDownBars = value;
    }

    /**
     * Gets the value of the marker property.
     *
     * @return
     *     possible object is
     *     {@link CTBoolean }
     *
     */
    public CTBoolean getMarker() {
        return marker;
    }

    /**
     * Sets the value of the marker property.
     *
     * @param value
     *     allowed object is
     *     {@link CTBoolean }
     *
     */
    public void setMarker(CTBoolean value) {
        this.marker = value;
    }

    /**
     * Gets the value of the smooth property.
     *
     * @return
     *     possible object is
     *     {@link CTBoolean }
     *
     */
    public CTBoolean getSmooth() {
        return smooth;
    }

    /**
     * Sets the value of the smooth property.
     *
     * @param value
     *     allowed object is
     *     {@link CTBoolean }
     *
     */
    public void setSmooth(CTBoolean value) {
        this.smooth = value;
    }

    /**
     * Gets the value of the axId property.
     *
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the axId property.
     *
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAxId().add(newItem);
     * </pre>
     *
     *
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTUnsignedInt }
     *
     *
     */
    @Override
    public List<CTUnsignedInt> getAxId() {
        if (axId == null) {
            axId = new ArrayList<CTUnsignedInt>();
        }
        return this.axId;
    }

    /**
     * Gets the value of the extLst property.
     *
     * @return
     *     possible object is
     *     {@link CTExtensionList }
     *
     */
    public CTExtensionList getExtLst() {
        return extLst;
    }

    /**
     * Sets the value of the extLst property.
     *
     * @param value
     *     allowed object is
     *     {@link CTExtensionList }
     *
     */
    public void setExtLst(CTExtensionList value) {
        this.extLst = value;
    }

    @Override
    public String getStacking() {
        return getGrouping().getVal().value();
    }

    @Override
    public void setGrouping(String stacking) {
        if(grouping==null) {
            grouping = new CTGrouping();
        }
        grouping.setVal(STGrouping.fromValue(stacking));

    }
}

==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.docx4j/src/main/java/org/docx4j/dml/chart/CTLineChart.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.

    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

 */


package org.docx4j.dml.chart;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;

import org.docx4j.dml.chart.layer.NoBarDirChart;
import org.docx4j.jaxb.Context;


/**
 * <p>Java class for CT_LineChart complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="CT_LineChart">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;group ref="{http://schemas.openxmlformats.org/drawingml/2006/chart}EG_LineChartShared"/>
 *         &lt;element name="hiLowLines" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_ChartLines" minOccurs="0"/>
 *         &lt;element name="upDownBars" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_UpDownBars" minOccurs="0"/>
 *         &lt;element name="marker" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_Boolean" minOccurs="0"/>
 *         &lt;element name="smooth" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_Boolean" minOccurs="0"/>
 *         &lt;element name="axId" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_UnsignedInt" maxOccurs="2" minOccurs="2"/>
 *         &lt;element name="extLst" type="{http://schemas.openxmlformats.org/drawingml/2006/chart}CT_ExtensionList" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_LineChart", propOrder = {
    "grouping",
    "varyColors",
    "ser",
    "dLbls",
    "dropLines",
    "hiLowLines",
    "upDownBars",
    "marker",
    "smooth",
    "axId",
    "extLst"
})
public class CTLineChart extends NoBarDirChart {

    @XmlElement(required = true)
    protected CTGrouping grouping;
    protected CTBoolean varyColors;
    @XmlElements({
        @XmlElement(name = "ser", type = CTLineSer.class)
    })
    protected List<ISerContent> ser;
    protected CTDLbls dLbls;
    protected CTChartLines dropLines;
    protected CTChartLines hiLowLines;
    protected CTUpDownBars upDownBars;
    protected CTBoolean marker;
    protected CTBoolean smooth;
    @XmlElement(required = true)
    protected List<CTUnsignedInt> axId;
    protected CTExtensionList extLst;

    /**
     * Gets the value of the grouping property.
     *
     * @return
     *     possible object is
     *     {@link CTGrouping }
     *
     */
    public CTGrouping getGrouping() {
        return grouping;
    }

    /**
     * Sets the value of the grouping property.
     *
     * @param value
     *     allowed object is
     *     {@link CTGrouping }
     *
     */
    public void setGrouping(CTGrouping value) {
        this.grouping = value;
    }

    /**
     * Gets the value of the varyColors property.
     *
     * @return
     *     possible object is
     *     {@link CTBoolean }
     *
     */
    @Override
    public CTBoolean getVaryColors() {
        return varyColors;
    }

    /**
     * Sets the value of the varyColors property.
     *
     * @param value
     *     allowed object is
     *     {@link CTBoolean }
     *
     */
    @Override
    public void setVaryColors(CTBoolean value) {
        this.varyColors = value;
    }

    /**
     * Gets the value of the ser property.
     *
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the ser property.
     *
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getSer().add(newItem);
     * </pre>
     *
     *
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTLineSer }
     *
     *
     */
    @Override
    public List<ISerContent> getSer() {
        if (ser == null) {
            ser = new ArrayList<ISerContent>();
        }
        return this.ser;
    }

    @Override
    public CTLineSer createSer() {
        return Context.getDmlChartObjectFactory().createCTLineSer();
    }

    /**
     * Gets the value of the dLbls property.
     *
     * @return
     *     possible object is
     *     {@link CTDLbls }
     *
     */
    @Override
    public CTDLbls getDLbls() {
        return dLbls;
    }

    /**
     * Sets the value of the dLbls property.
     *
     * @param value
     *     allowed object is
     *     {@link CTDLbls }
     *
     */
    @Override
    public void setDLbls(CTDLbls value) {
        this.dLbls = value;
    }

    /**
     * Gets the value of the dropLines property.
     *
     * @return
     *     possible object is
     *     {@link CTChartLines }
     *
     */
    public CTChartLines getDropLines() {
        return dropLines;
    }

    /**
     * Sets the value of the dropLines property.
     *
     * @param value
     *     allowed object is
     *     {@link CTChartLines }
     *
     */
    public void setDropLines(CTChartLines value) {
        this.dropLines = value;
    }

    /**
     * Gets the value of the hiLowLines property.
     *
     * @return
     *     possible object is
     *     {@link CTChartLines }
     *
     */
    public CTChartLines getHiLowLines() {
        return hiLowLines;
    }

    /**
     * Sets the value of the hiLowLines property.
     *
     * @param value
     *     allowed object is
     *     {@link CTChartLines }
     *
     */
    public void setHiLowLines(CTChartLines value) {
        this.hiLowLines = value;
    }

    /**
     * Gets the value of the upDownBars property.
     *
     * @return
     *     possible object is
     *     {@link CTUpDownBars }
     *
     */
    public CTUpDownBars getUpDownBars() {
        return upDownBars;
    }

    /**
     * Sets the value of the upDownBars property.
     *
     * @param value
     *     allowed object is
     *     {@link CTUpDownBars }
     *
     */
    public void setUpDownBars(CTUpDownBars value) {
        this.upDownBars = value;
    }

    /**
     * Gets the value of the marker property.
     *
     * @return
     *     possible object is
     *     {@link CTBoolean }
     *
     */
    public CTBoolean getMarker() {
        return marker;
    }

    /**
     * Sets the value of the marker property.
     *
     * @param value
     *     allowed object is
     *     {@link CTBoolean }
     *
     */
    public void setMarker(CTBoolean value) {
        this.marker = value;
    }

    /**
     * Gets the value of the smooth property.
     *
     * @return
     *     possible object is
     *     {@link CTBoolean }
     *
     */
    public CTBoolean getSmooth() {
        return smooth;
    }

    /**
     * Sets the value of the smooth property.
     *
     * @param value
     *     allowed object is
     *     {@link CTBoolean }
     *
     */
    public void setSmooth(CTBoolean value) {
        this.smooth = value;
    }

    /**
     * Gets the value of the axId property.
     *
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the axId property.
     *
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAxId().add(newItem);
     * </pre>
     *
     *
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTUnsignedInt }
     *
     *
     */
    @Override
    public List<CTUnsignedInt> getAxId() {
        if (axId == null) {
            axId = new ArrayList<CTUnsignedInt>();
        }
        return this.axId;
    }

    /**
     * Gets the value of the extLst property.
     *
     * @return
     *     possible object is
     *     {@link CTExtensionList }
     *
     */
    public CTExtensionList getExtLst() {
        return extLst;
    }

    /**
     * Sets the value of the extLst property.
     *
     * @param value
     *     allowed object is
     *     {@link CTExtensionList }
     *
     */
    public void setExtLst(CTExtensionList value) {
        this.extLst = value;
    }

    @Override
    public String getStacking() {
        if (null == grouping) { return null;}
        return grouping.getVal().value();
    }

    @Override
    public void setStacking(String stacking) {
        if(grouping==null) {
            grouping = new CTGrouping();
        }
        grouping.setVal(STGrouping.fromValue(stacking));

    }
}
